WallpaperPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • WallpaperPlatform
Implementers

Constructors

WallpaperPlatform()
Constructs a WallpaperPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPlatformVersion() Future<String?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setLiveWallpaper({String? path}) Future<void>
setWallpaper(String path) Future<String?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance WallpaperPlatform
The default instance of WallpaperPlatform to use.
getter/setter pair